%global srcname anyio

%bcond_without bootstrap

%if %{with bootstrap}
%bcond_with tests
%bcond_with doc
%else
%bcond_without tests
%bcond_without doc
%endif

%global common_description %{expand:
AnyIO is an asynchronous networking and concurrency library that works on top
of either asyncio or trio.  It implements trio-like structured concurrency (SC)
on top of asyncio, and works in harmony with the native SC of trio itself.}

Summary:        Compatibility layer for multiple asynchronous event loop implementations
Name:           python-%{srcname}
Version:        3.7.1
Release:        1%{?dist}
License:        MIT
URL:            https://github.com/agronholm/anyio
Source0:         %pypi_source

BuildArch:      noarch

%description %{common_description}

%package -n python3-%{srcname}
Summary:        Compatibility layer for multiple asynchronous event loop implementations
BuildRequires:  python3-devel

%description -n python3-%{srcname} %{common_description}

%package -n python3-anyio+trio
Summary: Metapackage for python3-anyio: trio extras
Requires: python3-%{srcname} = %{version}-%{release}

%description -n python3-anyio+trio
This is a metapackage bringing in trio extras requires for python3-anyio.
It makes sure the dependencies are installed.


%if %{with docs}
%package -n python-%{srcname}-doc
Summary:        anyio documentation

%description -n python-%{srcname}-doc
Documentation for anyio
%endif

%prep
%autosetup -n %{srcname}-%{version} -p1

sed -e '/"coverage/d' -i pyproject.toml

sed -i 's/"trio < 0.22"/"trio"/' pyproject.toml

rm tests/test_sockets.py


%generate_buildrequires
%pyproject_buildrequires -x trio%{?with_tests:,test}%{?with_docs:,doc}


%build
%pyproject_wheel
%if %{with docs}
PYTHONPATH=${PWD} sphinx-build-3 docs html
rm -rf html/.{doctrees,buildinfo}
%endif


%install
%pyproject_install
%pyproject_save_files %{srcname}


%if %{with tests}
%check
%pytest -Wdefault -m "not network" -k "not ((trio and exception_group) or test_properties)"
%endif


%files -n python3-%{srcname} -f %{pyproject_files}
%doc README.rst


%if %{with docs}
%files -n python-%{srcname}-doc
%doc html
%license LICENSE
%endif

%files -n python3-anyio+trio
%ghost %{python3_sitelib}/anyio-%{version}.dist-info

%changelog
* Thu Jun 13 2024 Shuo Wang <abushwang@tencent.com> - 3.7.1-1
- initial build
